==> kmyfirewall-trinity-3.5.13.2.tar.xz: kmyfirewall-trinity-3.5.13.2/kmyfirewall/ruleoptionplugins/nat_target_option/kmfruletargetoptioneditnat.h <==
/***************************************************************************
    Copyright (C) 2004 Christian Hubinger
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
//
// C++ Interface: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KMFRULETARGETOPTIONEDITNAT_H
#define KMFRULETARGETOPTIONEDITNAT_H

#include "../../core/kmfruletargetoptioneditinterface.h"

// KDE includes
#include <kparts/part.h>
#include <kparts/plugin.h>
#include <kparts/factory.h>
#include <kxmlgui.h>
class KInstance;
namespace KMF {
class IPTRule;
class KMFRuleEditorTargetNat;
/**
@author Christian Hubinger
*/
class KMFRuleTargetOptionEditNat : public KMFRuleTargetOptionEditInterface {
	Q_OBJECT
  TQ_OBJECT
public:
	KMFRuleTargetOptionEditNat(TQObject *parent = 0, const char *name = 0);

	~KMFRuleTargetOptionEditNat();
	void loadRule( IPTRule* rule );	
	TQWidget* editWidget();
	const TQString& optionEditName() const;
	const TQString& description() const;
	bool setTarget( const TQString& );

private slots:
	void slotShowOverview();

private:
	KMFRuleEditorTargetNat *m_edit;
	IPTRule *m_rule;
	
};



class KMFRuleTargetOptionEditNatFactory : public KLibFactory {
	Q_OBJECT
  TQ_OBJECT
public:
	KMFRuleTargetOptionEditNatFactory( TQObject *parent = 0, const char *name = 0 );
	virtual ~KMFRuleTargetOptionEditNatFactory() {
/* 		delete s_instance; */
	};
	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
	                               const TQStringList &args = TQStringList() );
	/*     static KInstance* instance(); */

/*private:
	static KInstance* s_instance;*/
};
}








#endif

==> kmyfirewall-trinity-14.0.12.tar.xz: kmyfirewall-trinity-14.0.12/kmyfirewall/ruleoptionplugins/nat_target_option/kmfruletargetoptioneditnat.h <==
/***************************************************************************
    Copyright (C) 2004 Christian Hubinger
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
//
// C++ Interface: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KMFRULETARGETOPTIONEDITNAT_H
#define KMFRULETARGETOPTIONEDITNAT_H

#include "../../core/kmfruletargetoptioneditinterface.h"

// KDE includes
#include <tdeparts/part.h>
#include <tdeparts/plugin.h>
#include <tdeparts/factory.h>
#include <kxmlgui.h>
class TDEInstance;
namespace KMF {
class IPTRule;
class KMFRuleEditorTargetNat;
/**
@author Christian Hubinger
*/
class KMFRuleTargetOptionEditNat : public KMFRuleTargetOptionEditInterface {
	Q_OBJECT
  
public:
	KMFRuleTargetOptionEditNat(TQObject *parent = 0, const char *name = 0);

	~KMFRuleTargetOptionEditNat();
	void loadRule( IPTRule* rule );	
	TQWidget* editWidget();
	const TQString& optionEditName() const;
	const TQString& description() const;
	bool setTarget( const TQString& );

private slots:
	void slotShowOverview();

private:
	KMFRuleEditorTargetNat *m_edit;
	IPTRule *m_rule;
	
};



class KMFRuleTargetOptionEditNatFactory : public KLibFactory {
	Q_OBJECT
  
public:
	KMFRuleTargetOptionEditNatFactory( TQObject *parent = 0, const char *name = 0 );
	virtual ~KMFRuleTargetOptionEditNatFactory() {
/* 		delete s_instance; */
	};
	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
	                               const TQStringList &args = TQStringList() );
	/*     static TDEInstance* instance(); */

/*private:
	static TDEInstance* s_instance;*/
};
}








#endif
